import BoxClient from '../box-client';
import * as schemas from '../schemas';
/**
 */
declare class ShieldInformationBarrierReportsManager {
    client: BoxClient;
    /**
     * @param {BoxClient} client The Box API Client that is responsible for making calls to the API
     */
    constructor(client: BoxClient);
    /**
     * Get shield information barrier report by ID
     *
     * Retrieves a shield information barrier report by its ID.
     * @param {object} options Options for the request
     * @param {string} options.shield_information_barrier_report_id The ID of the shield information barrier Report.
     * @param {Function} [callback] Passed the result if successful, error otherwise
     * @returns {Promise<schemas.ShieldInformationBarrierReport>} A promise resolving to the result or rejecting with an error
     */
    getById(options: {
        /**
         * The ID of the shield information barrier Report.
         */
        readonly shield_information_barrier_report_id: string;
    }, callback?: Function): Promise<schemas.ShieldInformationBarrierReport>;
    /**
     * List shield information barrier reports
     *
     * Lists shield information barrier reports with specific IDs.
     * @param {object} options Options for the request
     * @param {string} options.shield_information_barrier_id The ID of the shield information barrier.
     * @param {string} [options.marker] Defines the position marker at which to begin returning results. This is used when paginating using marker-based pagination. This requires `usemarker` to be set to `true`.
     * @param {number} [options.limit] The maximum number of items to return per page.
     * @param {Function} [callback] Passed the result if successful, error otherwise
     * @returns {Promise<object>} A promise resolving to the result or rejecting with an error
     */
    getAll(options: {
        /**
         * The ID of the shield information barrier.
         */
        readonly shield_information_barrier_id: string;
        /**
         * Defines the position marker at which to begin returning results. This is
         * used when paginating using marker-based pagination.
         *
         * This requires `usemarker` to be set to `true`.
         */
        readonly marker?: string;
        /**
         * The maximum number of items to return per page.
         */
        readonly limit?: number;
    }, callback?: Function): Promise<object>;
    /**
     * Create shield information barrier report
     *
     * Creates a shield information barrier report for a given barrier.
     * @param {schemas.ShieldInformationBarrierReference} body
     * @param {object} [options] Options for the request
     * @param {Function} [callback] Passed the result if successful, error otherwise
     * @returns {Promise<schemas.ShieldInformationBarrierReport>} A promise resolving to the result or rejecting with an error
     */
    create(body: schemas.ShieldInformationBarrierReference, options?: {}, callback?: Function): Promise<schemas.ShieldInformationBarrierReport>;
}
export = ShieldInformationBarrierReportsManager;
