import BoxClient from '../box-client';
import * as schemas from '../schemas';
/**
 */
declare class ShieldInformationBarrierManager {
    client: BoxClient;
    /**
     * @param {BoxClient} client The Box API Client that is responsible for making calls to the API
     */
    constructor(client: BoxClient);
    /**
     * Get shield information barrier with specified ID
     *
     * Get shield information barrier based on provided ID..
     * @param {object} options Options for the request
     * @param {string} options.shield_information_barrier_id The ID of the shield information barrier.
     * @param {Function} [callback] Passed the result if successful, error otherwise
     * @returns {Promise<schemas.ShieldInformationBarrier>} A promise resolving to the result or rejecting with an error
     */
    getById(options: {
        /**
         * The ID of the shield information barrier.
         */
        readonly shield_information_barrier_id: string;
    }, callback?: Function): Promise<schemas.ShieldInformationBarrier>;
    /**
     * List shield information barriers
     *
     * Retrieves a list of shield information barrier objects
     * for the enterprise of JWT.
     * @param {object} [options] Options for the request
     * @param {string} [options.marker] Defines the position marker at which to begin returning results. This is used when paginating using marker-based pagination. This requires `usemarker` to be set to `true`.
     * @param {number} [options.limit] The maximum number of items to return per page.
     * @param {Function} [callback] Passed the result if successful, error otherwise
     * @returns {Promise<object>} A promise resolving to the result or rejecting with an error
     */
    getAll(options?: {
        /**
         * Defines the position marker at which to begin returning results. This is
         * used when paginating using marker-based pagination.
         *
         * This requires `usemarker` to be set to `true`.
         */
        readonly marker?: string;
        /**
         * The maximum number of items to return per page.
         */
        readonly limit?: number;
    }, callback?: Function): Promise<object>;
    /**
     * Create shield information barrier
     *
     * Creates a shield information barrier to
     * separate individuals/groups within the same
     * firm and prevents confidential information passing between them.
     * @param {schemas.ShieldInformationBarrier} body
     * @param {object} [options] Options for the request
     * @param {Function} [callback] Passed the result if successful, error otherwise
     * @returns {Promise<schemas.ShieldInformationBarrier>} A promise resolving to the result or rejecting with an error
     */
    create(body: schemas.ShieldInformationBarrier, options?: {}, callback?: Function): Promise<schemas.ShieldInformationBarrier>;
    /**
     * Add changed status of shield information barrier with specified ID
     *
     * Change status of shield information barrier with the specified ID.
     * @param {object} body
     * @param {object} [options] Options for the request
     * @param {Function} [callback] Passed the result if successful, error otherwise
     * @returns {Promise<schemas.ShieldInformationBarrier>} A promise resolving to the result or rejecting with an error
     */
    changeStatusById(body: object, options?: {}, callback?: Function): Promise<schemas.ShieldInformationBarrier>;
}
export = ShieldInformationBarrierManager;
