"use strict";
/**
 * @fileoverview URL Path Builder
 */
// ------------------------------------------------------------------------------
// Private
// ------------------------------------------------------------------------------
// Pattern to check for relative paths
var PATTERN = /\/\.+/;
/**
 * remove leading & trailing slashes from some string. This is useful for
 * removing slashes from the path segments that are actually a part of the
 * path itself. Without this step, these slashes would be uri-encoded.
 *
 * @param {string} segment The path segment (ex: '/users')
 * @returns {string} The path segment with slashes trimmed (ex: 'users')
 * @private
 */
function trimSlashes(segment) {
    return segment.replace(/^\/|\/$/g, '');
}
module.exports = function urlPath() {
    var args = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
    }
    var path = args
        .map(function (x) { return String(x); })
        .map(function (x) {
        var trimmedX = trimSlashes(x);
        if (PATTERN.test(trimmedX)) {
            throw new Error("An invalid path parameter exists in ".concat(trimmedX, ". Relative path parameters cannot be passed."));
        }
        return trimmedX;
    })
        .map(function (x) { return encodeURIComponent(x); })
        .join('/');
    return "/".concat(path);
};
//# sourceMappingURL=url-path.js.map